Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(459)

Unified Diff: content/public/browser/resource_dispatcher_host.h

Issue 11068027: OnDownloadStarted takes DownloadItem* instead of DownloadId (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: @r160830 Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/browser/download_url_parameters.h ('k') | content/public/test/download_test_observer.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/resource_dispatcher_host.h
diff --git a/content/public/browser/resource_dispatcher_host.h b/content/public/browser/resource_dispatcher_host.h
index 403f6d3b6c0d86421005389525482b966f545fb5..848d55fd72c76a284c3b0588c45497348909a631 100644
--- a/content/public/browser/resource_dispatcher_host.h
+++ b/content/public/browser/resource_dispatcher_host.h
@@ -6,7 +6,6 @@
#define CONTENT_PUBLIC_BROWSER_RESOURCE_DISPATCHER_HOST_H_
#include "base/callback_forward.h"
-#include "content/public/browser/download_id.h"
#include "net/base/net_errors.h"
namespace net {
@@ -14,13 +13,16 @@ class URLRequest;
}
namespace content {
+
+class DownloadItem;
class ResourceContext;
class ResourceDispatcherHostDelegate;
struct DownloadSaveInfo;
class CONTENT_EXPORT ResourceDispatcherHost {
public:
- typedef base::Callback<void(DownloadId, net::Error)> DownloadStartedCallback;
+ typedef base::Callback<void(DownloadItem*, net::Error)>
+ DownloadStartedCallback;
// Returns the singleton instance of the ResourceDispatcherHost.
static ResourceDispatcherHost* Get();
@@ -35,10 +37,10 @@ class CONTENT_EXPORT ResourceDispatcherHost {
// Initiates a download by explicit request of the renderer, e.g. due to
// alt-clicking a link. If the download is started, |started_callback| will
// be called on the UI thread with the DownloadId; otherwise an error code
// will be returned. |is_content_initiated| is used to indicate that
// the request was generated from a web page, and hence may not be
// as trustworthy as a browser generated request.
virtual net::Error BeginDownload(
scoped_ptr<net::URLRequest> request,
bool is_content_initiated,
@@ -35,10 +37,10 @@ class CONTENT_EXPORT ResourceDispatcherHost {
// Initiates a download by explicit request of the renderer, e.g. due to
// alt-clicking a link. If the download is started, |started_callback| will
- // be called on the UI thread with the DownloadId; otherwise an error code
- // will be returned. |is_content_initiated| is used to indicate that
- // the request was generated from a web page, and hence may not be
- // as trustworthy as a browser generated request.
+ // be called on the UI thread with the DownloadItem; otherwise an error code
+ // will be returned. |is_content_initiated| is used to indicate that the
+ // request was generated from a web page, and hence may not be as trustworthy
+ // as a browser generated request.
virtual net::Error BeginDownload(
scoped_ptr<net::URLRequest> request,
« no previous file with comments | « content/public/browser/download_url_parameters.h ('k') | content/public/test/download_test_observer.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698